package com.ruoyi.brewery.mapper;

import java.util.List;
import com.ruoyi.brewery.domain.WyActivity;
import com.ruoyi.brewery.domain.WyActivityBar;
import com.ruoyi.brewery.domain.WyActivityFavorite;

/**
 * 营销活动Mapper接口
 * 
 * @author kxl
 * @date 2024-12-21
 */
public interface WyActivityMapper 
{
    /**
     * 查询营销活动
     * 
     * @param id 营销活动主键
     * @return 营销活动
     */
    public WyActivity selectWyActivityById(Long id);

    public Integer selectActivityCount(WyActivity wyActivity);

    /**
     * 查询营销活动列表
     * 
     * @param wyActivity 营销活动
     * @return 营销活动集合
     */
    public List<WyActivity> selectWyActivityList(WyActivity wyActivity);

    public List<WyActivity> selectFavoritedWyActivityList(WyActivityFavorite wyActivityFavorite);

    /**
     * 新增营销活动
     * 
     * @param wyActivity 营销活动
     * @return 结果
     */
    public int insertWyActivity(WyActivity wyActivity);

    /**
     * 修改营销活动
     * 
     * @param wyActivity 营销活动
     * @return 结果
     */
    public int updateWyActivity(WyActivity wyActivity);

    /**
     * 删除营销活动
     * 
     * @param id 营销活动主键
     * @return 结果
     */
    public int deleteWyActivityById(Long id);

    /**
     * 批量删除营销活动
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWyActivityByIds(Long[] ids);

    public List<WyActivityBar> selectWyActivityBarList(WyActivityBar bar);

    public int insertWyActivityBar(WyActivityBar bar);

    public WyActivityBar selectWyActivityBar(WyActivityBar bar);

    public int deleteWyActivityBarByActivityId(Long activityId);
    public int deleteWyActivityBarByBarId(Long barId);

}
